@@ -2,19 +2,23 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-import abc
+# import abc
 import functools
 
 
 __all__ = ['memoize']
 
 
-def add_metaclass(metaclass):
-    pass
-
-
 class abstractstatic(staticmethod):
-    __slots__ = []
+    """Decorator for declaring a static method abstract.
+
+    Parameters
+    ----------
+    function : callable
+        The method to declare abstract static.
+    """
+
+    __slots__ = ()
 
     def __init__(self, function):
         super(abstractstatic, self).__init__(function)
@@ -24,7 +28,13 @@ class abstractstatic(staticmethod):
 
 
 def memoize(func, *args, **kwargs):
-    """Decorator to wrap a function with a memoizing callable."""
+    """Decorator to wrap a function with a memoizing callable.
+
+    Parameters
+    ----------
+    func : callable
+        The function that should be memoized.
+    """
     cache = func.cache = {}
 
     @functools.wraps(func)
@@ -42,20 +52,4 @@ def memoize(func, *args, **kwargs):
 # ==============================================================================
 
 if __name__ == "__main__":
-
-    class A(object):
-        __metaclass__ = abc.ABCMeta
-
-        @abstractstatic
-        def test():
-            pass
-
-    class B(A):
-
-        @staticmethod
-        def test():
-            print(B.__metaclass__)
-
-    b = B()
-
-    b.test()
+    pass
