@@ -1,4 +1,3 @@
-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
@@ -17,12 +16,6 @@ from numpy import sqrt
 from numpy import zeros
 
 
-__author__    = ['Andrew Liew <liew@arch.ethz.ch>']
-__copyright__ = 'Copyright 2018, BLOCK Research Group - ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'liew@arch.ethz.ch'
-
-
 __all__ = [
     'sum_vectors_numba',
     'norm_vector_numba',
@@ -68,8 +61,7 @@ __all__ = [
 
 @jit(f8[:](f8[:, :], i8), nogil=True, nopython=True, parallel=False, cache=True)
 def sum_vectors_numba(a, axis=0):
-
-    """ Calculate the sum of an array of vectors along the specified axis.
+    """Calculate the sum of an array of vectors along the specified axis.
 
     Parameters
     ----------
@@ -81,9 +73,7 @@ def sum_vectors_numba(a, axis=0):
     Returns
     -------
     array: The summed values according to the axis of choice.
-
     """
-
     m = a.shape[0]
 
     if axis == 0:
@@ -103,8 +93,7 @@ def sum_vectors_numba(a, axis=0):
 
 @jit(f8(f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def norm_vector_numba(a):
-
-    """ Calculate the L2 norm or length of a vector.
+    """Calculate the L2 norm or length of a vector.
 
     Parameters
     ----------
@@ -114,16 +103,13 @@ def norm_vector_numba(a):
     Returns
     -------
     float: The L2 norm of the vector.
-
     """
-
     return sqrt(a[0]**2 + a[1]**2 + a[2]**2)
 
 
 @jit(f8[:](f8[:, :]), nogil=True, nopython=True, parallel=False, cache=True)
 def norm_vectors_numba(a):
-
-    """ Calculate the L2 norm or length of vectors.
+    """Calculate the L2 norm or length of vectors.
 
     Parameters
     ----------
@@ -133,9 +119,7 @@ def norm_vectors_numba(a):
     Returns
     -------
     array: The L2 norm of the vectors.
-
     """
-
     m = a.shape[0]
     w = zeros(m)
     for i in range(m):
@@ -145,8 +129,7 @@ def norm_vectors_numba(a):
 
 @jit(f8(f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def length_vector_numba(a):
-
-    """ Calculate the length of a vector.
+    """Calculate the length of a vector.
 
     Parameters
     ----------
@@ -156,16 +139,13 @@ def length_vector_numba(a):
     Returns
     -------
     float: The length of the vector.
-
     """
-
     return sqrt(a[0]**2 + a[1]**2 + a[2]**2)
 
 
 @jit(f8(f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def length_vector_xy_numba(a):
-
-    """ Calculate the length of the vector, assuming it lies in the XY plane.
+    """Calculate the length of the vector, assuming it lies in the XY plane.
 
     Parameters
     ----------
@@ -175,16 +155,13 @@ def length_vector_xy_numba(a):
     Returns
     -------
     float: The length of the XY component of the vector
-
     """
-
     return sqrt(a[0]**2 + a[1]**2)
 
 
 @jit(f8(f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def length_vector_sqrd_numba(a):
-
-    """ Calculate the squared length of the vector.
+    """Calculate the squared length of the vector.
 
     Parameters
     ----------
@@ -194,16 +171,13 @@ def length_vector_sqrd_numba(a):
     Returns
     -------
     float: The squared length of the XYZ components.
-
     """
-
     return a[0]**2 + a[1]**2 + a[2]**2
 
 
 @jit(f8(f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def length_vector_sqrd_xy_numba(a):
-
-    """ Calculate the squared length of the vector, assuming it lies in the XY plane.
+    """Calculate the squared length of the vector, assuming it lies in the XY plane.
 
     Parameters
     ----------
@@ -213,9 +187,7 @@ def length_vector_sqrd_xy_numba(a):
     Returns
     -------
     float: The squared length of the XY components.
-
     """
-
     return a[0]**2 + a[1]**2
 
 
@@ -223,8 +195,7 @@ def length_vector_sqrd_xy_numba(a):
 
 @jit(f8[:](f8[:], f8), nogil=True, nopython=True, parallel=False, cache=True)
 def scale_vector_numba(a, factor):
-
-    """ Scale a vector by a given factor.
+    """Scale a vector by a given factor.
 
     Parameters
     ----------
@@ -236,9 +207,7 @@ def scale_vector_numba(a, factor):
     Returns
     -------
     array: The scaled vector, factor * a.
-
     """
-
     b = zeros(3)
     b[0] = a[0] * factor
     b[1] = a[1] * factor
@@ -248,8 +217,7 @@ def scale_vector_numba(a, factor):
 
 @jit(f8[:](f8[:], f8), nogil=True, nopython=True, parallel=False, cache=True)
 def scale_vector_xy_numba(a, factor):
-
-    """ Scale a vector by a given factor, assuming it lies in the XY plane.
+    """Scale a vector by a given factor, assuming it lies in the XY plane.
 
     Parameters
     ----------
@@ -262,9 +230,7 @@ def scale_vector_xy_numba(a, factor):
     -------
     array
         The scaled vector, factor * a (XY).
-
     """
-
     b = zeros(3)
     b[0] = a[0] * factor
     b[1] = a[1] * factor
@@ -273,8 +239,7 @@ def scale_vector_xy_numba(a, factor):
 
 @jit(f8[:, :](f8[:, :], f8), nogil=True, nopython=True, parallel=False, cache=True)
 def scale_vectors_numba(a, factor):
-
-    """ Scale multiple vectors by a given factor.
+    """Scale multiple vectors by a given factor.
 
     Parameters
     ----------
@@ -286,9 +251,7 @@ def scale_vectors_numba(a, factor):
     Returns
     -------
     array: Scaled vectors.
-
     """
-
     m = a.shape[0]
     b = zeros((m, 3))
     for i in range(m):
@@ -298,8 +261,7 @@ def scale_vectors_numba(a, factor):
 
 @jit(f8[:, :](f8[:, :], f8), nogil=True, nopython=True, parallel=False, cache=True)
 def scale_vectors_xy_numba(a, factor):
-
-    """ Scale multiple vectors by a given factor, assuming they lie in the XY plane
+    """Scale multiple vectors by a given factor, assuming they lie in the XY plane
 
     Parameters
     ----------
@@ -312,9 +274,7 @@ def scale_vectors_xy_numba(a, factor):
     -------
     array
         Scaled vectors (XY).
-
     """
-
     m = a.shape[0]
     b = zeros((m, 3))
     for i in range(m):
@@ -324,8 +284,7 @@ def scale_vectors_xy_numba(a, factor):
 
 @jit(f8[:](f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def normalize_vector_numba(a):
-
-    """ Normalize a given vector.
+    """Normalize a given vector.
 
     Parameters
     ----------
@@ -336,10 +295,8 @@ def normalize_vector_numba(a):
     -------
     array
         The normalized vector.
-
     """
-
-    l = length_vector_numba(a)
+    l = length_vector_numba(a)  # noqa: E741
     b = zeros(3)
     b[0] = a[0] / l
     b[1] = a[1] / l
@@ -349,8 +306,7 @@ def normalize_vector_numba(a):
 
 @jit(f8[:](f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def normalize_vector_xy_numba(a):
-
-    """ Normalize a given vector, assuming it lies in the XY-plane.
+    """Normalize a given vector, assuming it lies in the XY-plane.
 
     Parameters
     ----------
@@ -361,10 +317,8 @@ def normalize_vector_xy_numba(a):
     -------
     array
         The normalized vector in the XY-plane (Z = 0.0).
-
     """
-
-    l = length_vector_xy_numba(a)
+    l = length_vector_xy_numba(a)  # noqa: E741
     b = zeros(3)
     b[0] = a[0] / l
     b[1] = a[1] / l
@@ -373,8 +327,7 @@ def normalize_vector_xy_numba(a):
 
 @jit(f8[:, :](f8[:, :]), nogil=True, nopython=True, parallel=False, cache=True)
 def normalize_vectors_numba(a):
-
-    """ Normalise multiple vectors.
+    """Normalise multiple vectors.
 
     Parameters
     ----------
@@ -385,9 +338,7 @@ def normalize_vectors_numba(a):
     -------
     array
         The normalized vectors.
-
     """
-
     m = a.shape[0]
     b = zeros((m, 3))
     for i in range(m):
@@ -397,8 +348,7 @@ def normalize_vectors_numba(a):
 
 @jit(f8[:, :](f8[:, :]), nogil=True, nopython=True, parallel=False, cache=True)
 def normalize_vectors_xy_numba(a):
-
-    """ Normalise multiple vectors, assuming they lie in the XY plane.
+    """Normalise multiple vectors, assuming they lie in the XY plane.
 
     Parameters
     ----------
@@ -409,9 +359,7 @@ def normalize_vectors_xy_numba(a):
     -------
     array
         The normalized vectors in the XY plane.
-
     """
-
     m = a.shape[0]
     b = zeros((m, 3))
     for i in range(m):
@@ -421,8 +369,7 @@ def normalize_vectors_xy_numba(a):
 
 @jit(f8[:](f8[:], f8), nogil=True, nopython=True, parallel=False, cache=True)
 def power_vector_numba(a, power):
-
-    """ Raise a vector to the given power.
+    """Raise a vector to the given power.
 
     Parameters
     ----------
@@ -435,16 +382,13 @@ def power_vector_numba(a, power):
     -------
     array
         a^power.
-
     """
-
     return array([a[0]**power, a[1]**power, a[2]**power])
 
 
 @jit(f8[:, :](f8[:, :], f8), nogil=True, nopython=True, parallel=False, cache=True)
 def power_vectors_numba(a, power):
-
-    """ Raise multiple vectors to the given power.
+    """Raise multiple vectors to the given power.
 
     Parameters
     ----------
@@ -457,9 +401,7 @@ def power_vectors_numba(a, power):
     -------
     array
         a^power.
-
     """
-
     m = a.shape[0]
     b = zeros((m, 3))
     for i in range(m):
@@ -469,8 +411,7 @@ def power_vectors_numba(a, power):
 
 @jit(f8[:](f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def square_vector_numba(a):
-
-    """ Raise a single vector to the power 2.
+    """Raise a single vector to the power 2.
 
     Parameters
     ----------
@@ -481,16 +422,13 @@ def square_vector_numba(a):
     -------
     array
         a^2.
-
     """
-
     return power_vector_numba(a, power=2.)
 
 
 @jit(f8[:, :](f8[:, :]), nogil=True, nopython=True, parallel=False, cache=True)
 def square_vectors_numba(a):
-
-    """ Raise multiple vectors to the power 2.
+    """Raise multiple vectors to the power 2.
 
     Parameters
     ----------
@@ -501,9 +439,7 @@ def square_vectors_numba(a):
     -------
     array
         a^2.
-
     """
-
     return power_vectors_numba(a, power=2.)
 
 
@@ -511,8 +447,7 @@ def square_vectors_numba(a):
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def add_vectors_numba(u, v):
-
-    """ Add two vectors.
+    """Add two vectors.
 
     Parameters
     ----------
@@ -525,16 +460,13 @@ def add_vectors_numba(u, v):
     -------
     array
         u + v.
-
     """
-
     return array([u[0] + v[0], u[1] + v[1], u[2] + v[2]])
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def add_vectors_xy_numba(u, v):
-
-    """ Add two vectors, assuming they lie in the XY-plane.
+    """Add two vectors, assuming they lie in the XY-plane.
 
     Parameters
     ----------
@@ -547,16 +479,13 @@ def add_vectors_xy_numba(u, v):
     -------
     array
         u + v (Z = 0.0).
-
     """
-
     return array([u[0] + v[0], u[1] + v[1], 0.])
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def subtract_vectors_numba(u, v):
-
-    """ Subtract one vector from another.
+    """Subtract one vector from another.
 
     Parameters
     ----------
@@ -569,16 +498,13 @@ def subtract_vectors_numba(u, v):
     -------
     array
         u - v.
-
     """
-
     return array([u[0] - v[0], u[1] - v[1], u[2] - v[2]])
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def subtract_vectors_xy_numba(u, v):
-
-    """ Subtract one vector from another, assuming they lie in the XY plane.
+    """Subtract one vector from another, assuming they lie in the XY plane.
 
     Parameters
     ----------
@@ -591,16 +517,13 @@ def subtract_vectors_xy_numba(u, v):
     -------
     array
         u - v (Z = 0.0).
-
     """
-
     return array([u[0] - v[0], u[1] - v[1], 0.])
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def multiply_vectors_numba(u, v):
-
-    """ Element-wise multiplication of two vectors.
+    """Element-wise multiplication of two vectors.
 
     Parameters
     ----------
@@ -613,16 +536,13 @@ def multiply_vectors_numba(u, v):
     -------
     array
         [ui * vi, uj * vj, uk * vk].
-
     """
-
     return array([u[0] * v[0], u[1] * v[1], u[2] * v[2]])
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def multiply_vectors_xy_numba(u, v):
-
-    """ Element-wise multiplication of two vectors assumed to lie in the XY plane..
+    """Element-wise multiplication of two vectors assumed to lie in the XY plane..
 
     Parameters
     ----------
@@ -635,16 +555,13 @@ def multiply_vectors_xy_numba(u, v):
     -------
     array
         [ui * vi, uj * vj, (Z = 0.0)].
-
     """
-
     return array([u[0] * v[0], u[1] * v[1], 0.])
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def divide_vectors_numba(u, v):
-
-    """ Element-wise division of two vectors.
+    """Element-wise division of two vectors.
 
     Parameters
     ----------
@@ -657,16 +574,13 @@ def divide_vectors_numba(u, v):
     -------
     array
         [ui / vi, uj / vj, uk / vk].
-
     """
-
     return array([u[0] / v[0], u[1] / v[1], u[2] / v[2]])
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def divide_vectors_xy_numba(u, v):
-
-    """ Element-wise division of two vectors assumed to lie in the XY plane.
+    """Element-wise division of two vectors assumed to lie in the XY plane.
 
     Parameters
     ----------
@@ -679,9 +593,7 @@ def divide_vectors_xy_numba(u, v):
     -------
     array
         [ui / vi, uj / vj, (Z = 0.0)].
-
     """
-
     return array([u[0] / v[0], u[1] / v[1], 0.])
 
 
@@ -689,8 +601,7 @@ def divide_vectors_xy_numba(u, v):
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def cross_vectors_numba(u, v):
-
-    """ Compute the cross product of two vectors.
+    """Compute the cross product of two vectors.
 
     Parameters
     ----------
@@ -703,9 +614,7 @@ def cross_vectors_numba(u, v):
     -------
     array
         u X v.
-
     """
-
     w = zeros(3)
     w[0] = u[1] * v[2] - u[2] * v[1]
     w[1] = u[2] * v[0] - u[0] * v[2]
@@ -715,8 +624,7 @@ def cross_vectors_numba(u, v):
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def cross_vectors_xy_numba(u, v):
-
-    """ Compute the cross product of two vectors, assuming they lie in the XY-plane.
+    """Compute the cross product of two vectors, assuming they lie in the XY-plane.
 
     Parameters
     ----------
@@ -729,16 +637,13 @@ def cross_vectors_xy_numba(u, v):
     -------
     array
         u X v.
-
     """
-
     return array([0., 0., u[0] * v[1] - u[1] * v[0]])
 
 
 @jit(f8(f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def dot_vectors_numba(u, v):
-
-    """ Compute the dot product of two vectors.
+    """Compute the dot product of two vectors.
 
     Parameters
     ----------
@@ -751,16 +656,13 @@ def dot_vectors_numba(u, v):
     -------
     float
         u . v.
-
     """
-
     return u[0] * v[0] + u[1] * v[1] + u[2] * v[2]
 
 
 @jit(f8(f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def dot_vectors_xy_numba(u, v):
-
-    """ Compute the dot product of two vectors, assuming they lie in the XY-plane.
+    """Compute the dot product of two vectors, assuming they lie in the XY-plane.
 
     Parameters
     ----------
@@ -773,16 +675,13 @@ def dot_vectors_xy_numba(u, v):
     -------
     float
         u . v (Z = 0.0).
-
     """
-
     return u[0] * v[0] + u[1] * v[1]
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def vector_component_numba(u, v):
-
-    """ Compute the component of u in the direction of v.
+    """Compute the component of u in the direction of v.
 
     Parameters
     ----------
@@ -795,16 +694,13 @@ def vector_component_numba(u, v):
     -------
     float
         The component of u in the direction of v.
-
     """
-
     factor = dot_vectors_numba(u, v) / length_vector_sqrd_numba(v)
     return scale_vector_numba(v, factor)
 
 
 @jit(f8[:](f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def vector_component_xy_numba(u, v):
-
     """Compute the component of u in the direction of v, assuming they lie in the XY-plane.
 
     Parameters
@@ -818,9 +714,7 @@ def vector_component_xy_numba(u, v):
     -------
     float
         The component of u in the direction of v (Z = 0.0).
-
     """
-
     factor = dot_vectors_xy_numba(u, v) / length_vector_sqrd_xy_numba(v)
     return scale_vector_xy_numba(v, factor)
 
@@ -829,8 +723,7 @@ def vector_component_xy_numba(u, v):
 
 @jit(f8[:, :](f8[:, :]), nogil=True, nopython=True, parallel=False, cache=True)
 def orthonormalize_vectors_numba(a):
-
-    """ Orthonomalise a set of vectors using the Gram-Schmidt process.
+    """Orthonomalise a set of vectors using the Gram-Schmidt process.
 
     Parameters
     ----------
@@ -841,9 +734,7 @@ def orthonormalize_vectors_numba(a):
     -------
     array
         Array of othonormal basis for the input vectors.
-
     """
-
     m = a.shape[0]
     b = zeros((m, 3))
     b[0, :] = a[0, :]
@@ -857,8 +748,7 @@ def orthonormalize_vectors_numba(a):
 
 @jit(f8[:](f8[:], f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def plane_from_points_numba(u, v, w):
-
-    """ Construct a plane from three points.
+    """Construct a plane from three points.
 
     Parameters
     ----------
@@ -873,9 +763,7 @@ def plane_from_points_numba(u, v, w):
     -------
     array
         Normalised vector
-
     """
-
     uv = subtract_vectors_numba(v, u)
     uw = subtract_vectors_numba(w, u)
     p = normalize_vector_numba(cross_vectors_numba(uv, uw))
@@ -884,8 +772,7 @@ def plane_from_points_numba(u, v, w):
 
 @jit(f8[:](f8[:], f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def circle_from_points_numba(a, b, c):
-
-    """ Construct a circle from three points.
+    """Construct a circle from three points.
 
     Parameters
     ----------
@@ -900,9 +787,7 @@ def circle_from_points_numba(a, b, c):
     -------
     array
         (xyz, r, normal) x, y, z center, radius, nx, ny, nz normal.
-
     """
-
     ab = subtract_vectors_numba(b, a)
     cb = subtract_vectors_numba(b, c)
     ba = subtract_vectors_numba(a, b)
@@ -932,8 +817,7 @@ def circle_from_points_numba(a, b, c):
 
 @jit(f8[:](f8[:], f8[:], f8[:]), nogil=True, nopython=True, parallel=False, cache=True)
 def circle_from_points_xy_numba(u, v, w):
-
-    """ Construct a circle from three points assumed to be in the XY plane.
+    """Construct a circle from three points assumed to be in the XY plane.
 
     Parameters
     ----------
@@ -972,69 +856,69 @@ def circle_from_points_xy_numba(u, v, w):
 # ==============================================================================
 
 if __name__ == "__main__":
+    pass
 
-    from numpy.random import rand
+    # from numpy.random import rand
 
-    from time import time
+    # from time import time
 
-    u = array([1., 2., 3.])
-    v = array([4., 5., 6.])
-    w = array([5., 2., 10.])
-    c = array([[1., 2., 3.], [4., 4., 4.]])
-    d = array([4., 5.])
-    e = array([[1., 2.], [0., 2.]])
-    f = array([[4., 5.], [1., 2.]])
+    # u = array([1., 2., 3.])
+    # v = array([4., 5., 6.])
+    # w = array([5., 2., 10.])
+    # c = array([[1., 2., 3.], [4., 4., 4.]])
+    # d = array([4., 5.])
+    # e = array([[1., 2.], [0., 2.]])
+    # f = array([[4., 5.], [1., 2.]])
 
-    tic = time()
+    # tic = time()
 
-    for i in range(10**6):
+    # for i in range(10**6):
 
-        # a = sum_vectors_numba(c, axis=0)
-        # a = norm_vector_numba(u)
-        # a = norm_vectors_numba(c)
-        # a = length_vector_numba(u)
-        # a = length_vector_xy_numba(u)
-        # a = length_vector_sqrd_numba(u)
-        # a = length_vector_sqrd_xy_numba(u)
+    #     # a = sum_vectors_numba(c, axis=0)
+    #     # a = norm_vector_numba(u)
+    #     # a = norm_vectors_numba(c)
+    #     # a = length_vector_numba(u)
+    #     # a = length_vector_xy_numba(u)
+    #     # a = length_vector_sqrd_numba(u)
+    #     # a = length_vector_sqrd_xy_numba(u)
 
-        a = scale_vector_numba(u, factor=4.)
-        # a = scale_vector_xy_numba(u, factor=4.)
-        # a = scale_vectors_numba(c, factor=4.)
-        # a = scale_vectors_xy_numba(c, factor=4.)
-        # a = normalize_vector_numba(u)
-        # a = normalize_vector_xy_numba(u)
-        # a = normalize_vectors_numba(c)
-        # a = normalize_vectors_xy_numba(c)
-        # a = power_vector_numba(u, 3.)
-        # a = power_vectors_numba(c, 3.)
-        # a = square_vector_numba(u)
-        # a = square_vectors_numba(c)
+    #     a = scale_vector_numba(u, factor=4.)
+    #     # a = scale_vector_xy_numba(u, factor=4.)
+    #     # a = scale_vectors_numba(c, factor=4.)
+    #     # a = scale_vectors_xy_numba(c, factor=4.)
+    #     # a = normalize_vector_numba(u)
+    #     # a = normalize_vector_xy_numba(u)
+    #     # a = normalize_vectors_numba(c)
+    #     # a = normalize_vectors_xy_numba(c)
+    #     # a = power_vector_numba(u, 3.)
+    #     # a = power_vectors_numba(c, 3.)
+    #     # a = square_vector_numba(u)
+    #     # a = square_vectors_numba(c)
 
-        # a = add_vectors_numba(u, v)
-        # a = add_vectors_xy_numba(u, v)
-        # a = subtract_vectors_numba(u, v)
-        # a = subtract_vectors_xy_numba(u, v)
-        # a = multiply_vectors_numba(u, v)
-        # a = multiply_vectors_xy_numba(u, v)
-        # a = divide_vectors_numba(u, v)
-        # a = divide_vectors_xy_numba(u, v)
+    #     # a = add_vectors_numba(u, v)
+    #     # a = add_vectors_xy_numba(u, v)
+    #     # a = subtract_vectors_numba(u, v)
+    #     # a = subtract_vectors_xy_numba(u, v)
+    #     # a = multiply_vectors_numba(u, v)
+    #     # a = multiply_vectors_xy_numba(u, v)
+    #     # a = divide_vectors_numba(u, v)
+    #     # a = divide_vectors_xy_numba(u, v)
 
-        # a = cross_vectors_numba(u, v)
-        # a = cross_vectors_xy_numba(u, v)
-        # a = dot_vectors_numba(u, v)
-        # a = dot_vectors_xy_numba(u, v)
-        # a = vector_component_numba(u, v)
-        # a = vector_component_xy_numba(u, v)
+    #     # a = cross_vectors_numba(u, v)
+    #     # a = cross_vectors_xy_numba(u, v)
+    #     # a = dot_vectors_numba(u, v)
+    #     # a = dot_vectors_xy_numba(u, v)
+    #     # a = vector_component_numba(u, v)
+    #     # a = vector_component_xy_numba(u, v)
 
+    #     # a = orthonormalize_vectors_numba(c)
+    #     # a = plane_from_points_numba(u, v, w)
+    #     # a = circle_from_points_numba(u, v, w)
+    #     # a = circle_from_points_xy_numba(u, v, w)
 
-        # a = orthonormalize_vectors_numba(c)
-        # a = plane_from_points_numba(u, v, w)
-        # a = circle_from_points_numba(u, v, w)
-        # a = circle_from_points_xy_numba(u, v, w)
+    # # a = rand(10**7, 3)
 
-    # a = rand(10**7, 3)
+    # # sum_vectors_numba(a, 1)
 
-    # sum_vectors_numba(a, 1)
-
-    print(time() - tic)
-    # print(a)
+    # print(time() - tic)
+    # # print(a)
